@@ -3,7 +3,7 @@ import simplejson as json
 from django import template
 from django.core.serializers import serialize
 from django.db.models import QuerySet
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.functional import Promise
 from django.utils.safestring import mark_safe
 
@@ -20,7 +20,7 @@ def jsonify(object):
         if hasattr(obj, 'isoformat'):
             return obj.isoformat()
         elif isinstance(obj, Promise):
-            return force_text(obj)
+            return force_str(obj)
 
     if isinstance(object, QuerySet):
         return serialize('json', object)
